@@ -28,7 +28,10 @@ class TranslatableLanguageSelector(LanguageSelector):
             else:
                 state = getMultiAdapter((self.context, self.request),
                         name='plone_context_state')
-                data['url'] = state.view_url() + '?set_language=' + data['code']
+                try:
+                    data['url'] = state.view_url() + '?set_language=' + data['code']
+                except AttributeError:
+                    data['url'] = self.context.absolute_url() + '?set_language=' + data['code']
 
         return results
 
